==> hugo_0.80.0.orig.tar.gz: hugo-0.80.0/docs/content/en/showcase/quiply-employee-communications-app/index.md <==
---

# A suitable title for this article.
title: Quiply Employee Communications App

# Set this to the current date.
date: 2018-02-13

description: "\"It became immediately clear that we'd use Hugo going forward as it compiles super-fast, is intuitive to use and offers all the features we need.\""

# The URL to the site on the internet.
siteURL: https://www.quiply.com

# Link to the site's Hugo source code if public and you can/want to share.
# Remove or leave blank if not needed/wanted.
# siteSource: https://github.com/gohugoio/hugoDocs

# Add credit to the article author. Leave blank or remove if not needed/wanted.
byline: "[Sebastian Schirmer](mailto:sebastian.schirmer@quiply.com), Quiply Co-Founder"

---

With the launch of our Employee Communications app Quiply we created a very simple and static one-page website to showcase our product.

As our customer base and demand for marketing and communication started to grow, we needed a solution to easily grow and extend the contents of our web presence. As we do not have the need to serve dynamic content, we decided to use a static site generator. Amongst a couple of others, we tried Hugo and it became immediately clear that we'd use Hugo going forward as it compiles super-fast, is intuitive to use and offers all the features we need.

Our website which we launched a couple of weeks ago is still growing and new content is being added constantly. By using Hugo, this can be easily done by content authors writing markdown files without always having to touch HTML or CSS code. It is available in German only for the time being, an English version is in the works.

Huge thanks to everyone involved in making Hugo a success.

==> hugo_0.131.0.orig.tar.gz: hugo-0.131.0/docs/content/en/showcase/quiply-employee-communications-app/index.md <==
---

# A suitable title for this article.
title: Quiply Employee Communications App

# Set this to the current date.
date: 2018-02-13

description: "\"It became immediately clear that we'd use Hugo going forward as it compiles super-fast, is intuitive to use and offers all the features we need.\""

# The URL to the site on the internet.
siteURL: https://www.quiply.com

# Link to the site's Hugo source code if public and you can/want to share.
# Remove or leave blank if not needed/wanted.
# siteSource: https://github.com/gohugoio/hugoDocs

# Add credit to the article author. Leave blank or remove if not needed/wanted.
byline: "[Sebastian Schirmer](mailto:sebastian.schirmer@quiply.com), Quiply Co-Founder"

---

With the launch of our Employee Communications app Quiply we created a very simple and static one-page website to showcase our product.

As our customer base and demand for marketing and communication started to grow, we needed a solution to easily grow and extend the contents of our web presence. As we do not have the need to serve dynamic content, we decided to use a static site generator. Amongst a couple of others, we tried Hugo and it became immediately clear that we'd use Hugo going forward as it compiles super-fast, is intuitive to use and offers all the features we need.

Our website which we launched a couple of weeks ago is still growing and new content is being added constantly. By using Hugo, this can be easily done by content authors writing Markdown files without always having to touch HTML or CSS code. It is available in German only for the time being, an English version is in the works.

Huge thanks to everyone involved in making Hugo a success.
